@@ -1,4 +1,3 @@
-from pthflops.utils import print_table
 from .ops_jit import count_ops_jit
 try:
     from .ops_fx import count_ops_fx
@@ -7,7 +6,7 @@ except:
     force_jit = True
     print('Unable to import torch.fx, you pytorch version may be too old.')
 
-__version__ = '0.4.1'
+__version__ = '0.4.2'
 
 
 def count_ops(model, input, mode='fx', custom_ops={}, ignore_layers=[], print_readable=True, verbose=True, *args):
@@ -17,7 +16,7 @@ def count_ops(model, input, mode='fx', custom_ops={}, ignore_layers=[], print_re
             input,
             custom_ops=custom_ops,
             ignore_layers=ignore_layers,
-            print_readable=print_table,
+            print_readable=print_readable,
             verbose=verbose,
             *args)
     elif 'jit' == mode or force_jit:
@@ -28,7 +27,7 @@ def count_ops(model, input, mode='fx', custom_ops={}, ignore_layers=[], print_re
             input,
             custom_ops=custom_ops,
             ignore_layers=ignore_layers,
-            print_readable=print_table,
+            print_readable=print_readable,
             verbose=verbose,
             *args)
     else:
